@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.15';
+$Net::Kubernetes::VERSION = '0.16';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -94,11 +94,11 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 SYNOPSIS
 
-  my $kube = Net::Kubernets->new(url=>'http://127.0.0.1:8080', username=>'dave', password=>'davespassword');
+  my $kube = Net::Kubernetes->new(url=>'http://127.0.0.1:8080', username=>'dave', password=>'davespassword');
   my $pod_list = $kube->list_pods();
 
   my $nginx_pod = $kube->create_from_file('kubernetes/examples/pod.yaml');
@@ -176,7 +176,7 @@ returns a list of L<Net::Kubernetes::Resource::Node>s
 
 <h2>Build Status</h2>
 
-<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.15" />
+<img src="https://travis-ci.org/perljedi/net-kubernetes.svg?branch=release-0.16" />
 
 =end html
 
