@@ -1,6 +1,6 @@
 package Net::Kubernetes::Resource::Role::HasPods;
 # ABSTRACT: Resource role for types that may contain pods
-$Net::Kubernetes::Resource::Role::HasPods::VERSION = '0.15';
+$Net::Kubernetes::Resource::Role::HasPods::VERSION = '0.16';
 use Moose::Role;
 
 with 'Net::Kubernetes::Role::APIAccess';
@@ -10,6 +10,7 @@ sub get_pods {
 	my($self) = @_;
 	my $uri = URI->new_abs("../pods", $self->path);
 	$uri->query_form(labelSelector=>$self->_build_selector_from_hash($self->spec->{selector}));
+	print "Fetching pods with $uri\n";
 	my $res = $self->ua->request($self->create_request(GET => $uri));
 	if ($res->is_success) {
 		my $pod_list = $self->json->decode($res->content);
@@ -36,7 +37,7 @@ sub _build_selector_from_hash {
 	foreach my $label (keys %{ $select_hash }){
 		push @selectors, $label.'='.$select_hash->{$label};
 	}
-	return \@selectors;
+	return join(",", @selectors);
 }
 
 return 42;
@@ -53,7 +54,7 @@ Net::Kubernetes::Resource::Role::HasPods - Resource role for types that may cont
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 METHODS
 
